import unittest
import random
import facturama



class BaseEndpointTestCase(unittest.TestCase):
    random.seed()

    client = facturama

    customer_object = {
        "Id": "1111000",
        "Email": "test@test.com",
        "EmailOp1": "",
        "EmailOp2": "",
        "Rfc": "CACX7605101P8",
        "Name": "RXOCHILT CASAS CHAVEZ",
        "CfdiUse": "P01",
        "TaxResidence": "10740",
        "FiscalRegime":"605",
        "NumRegIdTrib": "",
        "Address": {
            "Street": "Calle de pruebas",
            "ExteriorNumber": "123",
            "InteriorNumber": "456",
            "Neighborhood": "Santa Teresa",
            "ZipCode": "10740",
            "Locality": "Ciudad de México",
            "Municipality": "La Magdalena Contreras",
            "State": "Distrito Federal",
            "Country": "Mex"
        }
    }

    product_object = {
      "Unit": "Servicio",
      "UnitCode": "E48",
      "IdentificationNumber": "WEB003",
      "Name": "Sitio Web CMS",
      "Description": "Desarrollo de sitio web empleando un CMS",
      "Price": 6500,
      "CodeProdServ": "43232408",
      "CuentaPredial": "123",
      "Taxes": [
        {
          "Name": "IVA",
          "Rate": 0.16,
          "IsRetention": False,
          "IsFederalTax": True
        },
        {
          "Name": "ISR",
          "IsRetention": True,
          "IsFederalTax": True,
          "Total": 0.10
        },
        {
          "Name": "IVA",
          "IsRetention": True,
          "IsFederalTax": True,
          "Total": 0.106667
        }
      ]
    }
    
    branch_office_object = {
        "Name": "Corp Inc",
        "Description": "Desc corp",
        "Address": {
            "Street": "Fenix One",
            "ExteriorNumber": "1",
            "InteriorNumber": "0",
            "Neighborhood": "Call me",
            "ZipCode": "59510",
            "Locality": "Xiquilpan",
            "Municipality": "Jiquilpan",
            "State": "MICHOACAN DE OCAMPO",
            "Country": "MX"
        },
    }

    cfdi_object ={
        "Folio": "100",
        "Serie": "B",
        "Currency": "MXN",
        "ExpeditionPlace": "78140",
        "PaymentConditions": "CREDITO A SIETE DIAS",
        "CfdiType": "I",
        "PaymentForm": "03",
        "PaymentMethod": "PUE",
        "Receiver": {
            "Rfc": "URE180429TM6",
            "Name": "UNIVERSIDAD ROBOTICA ESPAÑOLA",
            "CfdiUse": "G03",
            "FiscalRegime": "601",
            "TaxZipCode": "65000"
        },
        "Items": [
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "EDL",
                "Description": "Estudios de viabilidad",
                "Unit": "NO APLICA",
                "UnitCode": "MTS",
                "UnitPrice": 50.0,
                "Quantity": 2.0,
                "Subtotal": 100.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 16.0,
                        "Name": "IVA",
                        "Base": 100.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 116.0
            },
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "001",
                "Description": "SERVICIO DE COLOCACION",
                "Unit": "NO APLICA",
                "UnitCode": "E49",
                "UnitPrice": 100.0,
                "Quantity": 15.0,
                "Subtotal": 1500.0,
                "Discount": 0.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 240.0,
                        "Name": "IVA",
                        "Base": 1500.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 1740.0
            }
        ]
    }

    cfdi_object_40 ={
        "Folio": "100",
        "Serie": "B",
        "Currency": "MXN",
        "ExpeditionPlace": "78140",
        "PaymentConditions": "CREDITO A SIETE DIAS",
        "CfdiType": "I",
        "PaymentForm": "03",
        "PaymentMethod": "PUE",
        "Receiver": {
            "Rfc": "URE180429TM6",
            "Name": "UNIVERSIDAD ROBOTICA ESPAÑOLA",
            "CfdiUse": "CP01",
            "FiscalRegime": "601",
            "TaxZipCode": "65000"
        },
        "Items": [
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "EDL",
                "Description": "Estudios de viabilidad",
                "Unit": "NO APLICA",
                "UnitCode": "MTS",
                "UnitPrice": 50.0,
                "Quantity": 2.0,
                "Subtotal": 100.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 16.0,
                        "Name": "IVA",
                        "Base": 100.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 116.0
            },
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "001",
                "Description": "SERVICIO DE COLOCACION",
                "Unit": "NO APLICA",
                "UnitCode": "E49",
                "UnitPrice": 100.0,
                "Quantity": 15.0,
                "Subtotal": 1500.0,
                "Discount": 0.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 240.0,
                        "Name": "IVA",
                        "Base": 1500.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 1740.0
            }
        ]
    }

    cfdi_object_40_mult ={
        "Folio": "100",
        "Serie": "B",
        "Currency": "MXN",
        "ExpeditionPlace": "78140",
        "PaymentConditions": "CREDITO A SIETE DIAS",
        "CfdiType": "I",
        "PaymentForm": "03",
        "PaymentMethod": "PUE",
        "Issuer": {
            "Rfc":"EKU9003173C9",
            "Name":"ESCUELA KEMPER URGATE",
            "CfdiUse":"G03",
            "FiscalRegime":"601"
        },
        "Receiver": {
            "Rfc": "URE180429TM6",
            "Name": "UNIVERSIDAD ROBOTICA ESPAÑOLA",
            "CfdiUse": "CP01",
            "FiscalRegime": "601",
            "TaxZipCode": "65000"
        },
        "Items": [
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "EDL",
                "Description": "Estudios de viabilidad",
                "Unit": "NO APLICA",
                "UnitCode": "MTS",
                "UnitPrice": 50.0,
                "Quantity": 2.0,
                "Subtotal": 100.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 16.0,
                        "Name": "IVA",
                        "Base": 100.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 116.0
            },
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "001",
                "Description": "SERVICIO DE COLOCACION",
                "Unit": "NO APLICA",
                "UnitCode": "E49",
                "UnitPrice": 100.0,
                "Quantity": 15.0,
                "Subtotal": 1500.0,
                "Discount": 0.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 240.0,
                        "Name": "IVA",
                        "Base": 1500.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 1740.0
            }
        ]
    }
  
    cfdi_object_FacturaGlobal ={
        "Folio": "100",
        "Serie": "B",
        "Currency": "MXN",
        "ExpeditionPlace": "78140",
        "PaymentConditions": "CFDI 4.0 de prueba ",
        "CfdiType": "I",
        "PaymentForm": "03",
        "PaymentMethod": "PUE",
        "Exportation":"01",
        "GlobalInformation":{ 
            "Periodicity":"04",
            "Months":"04",
            "Year":"2022"
        },
        "Receiver": {
            "Rfc": "XAXX010101000",
            "Name": "PUBLICO EN GENERAL",
            "CfdiUse": "S01",
            "TaxZipCode": "78140",
            "FiscalRegime":"616"
        },
        "Items": [
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "EDL",
                "Description": "Estudios de viabilidad",
                "Unit": "NO APLICA",
                "UnitCode": "MTS",
                "UnitPrice": 50.0,
                "Quantity": 2.0,
                "Subtotal": 100.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 16.0,
                        "Name": "IVA",
                        "Base": 100.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 116.0
            }
        ]
    }

    cfdi_object_FacturaGlobal_mult ={
        "Folio": "100",
        "Serie": "B",
        "Currency": "MXN",
        "ExpeditionPlace": "78140",
        "PaymentConditions": "CFDI 4.0 de prueba ",
        "CfdiType": "I",
        "PaymentForm": "03",
        "PaymentMethod": "PUE",
        "Exportation":"01",
        "GlobalInformation":{ 
            "Periodicity":"04",
            "Months":"04",
            "Year":"2022"
        },
        "Issuer": {
            "Rfc": "EKU9003173C9",
            "Name": "ESCUELA KEMPER URGATE",
            "FiscalRegime": "601"
        },
        "Receiver": {
            "Rfc": "XAXX010101000",
            "Name": "PUBLICO EN GENERAL",
            "CfdiUse": "S01",
            "TaxZipCode": "78140",
            "FiscalRegime":"616"
        },
        "Items": [
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "EDL",
                "Description": "Estudios de viabilidad",
                "Unit": "NO APLICA",
                "UnitCode": "MTS",
                "UnitPrice": 50.0,
                "Quantity": 2.0,
                "Subtotal": 100.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 16.0,
                        "Name": "IVA",
                        "Base": 100.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 116.0
            },
            {
                "ProductCode": "10101504",
                "IdentificationNumber": "001",
                "Description": "SERVICIO DE COLOCACION",
                "Unit": "NO APLICA",
                "UnitCode": "E49",
                "UnitPrice": 100.0,
                "Quantity": 15.0,
                "Subtotal": 1500.0,
                "Discount": 0.0,
                "TaxObject":"02",
                "Taxes": [
                    {
                        "Total": 240.0,
                        "Name": "IVA",
                        "Base": 1500.0,
                        "Rate": 0.16,
                        "IsRetention": False
                    }
                ],
                "Total": 1740.0
            }
        ]
    }

    cfdi_object_complemento_pago = {
        "Receiver": {
            "Name": "SERVICIOS ADMINISTRATIVOS AXKAN DEL BAJIO S.C",
            "CfdiUse": "P01",
            "Rfc": "XEXX010101000"
        },
        "CfdiType": "P",
        "NameId": "1",
        "Folio": "93",
        "ExpeditionPlace": "51873",
        "Complemento": {
            "Payments": [{
                "Date": "2018-10-04",
                "PaymentForm": "03",
                "Amount": "11142.21",
                "RelatedDocuments": [{
                    "Uuid": "C94C8AF3-C774-4D4C-802E-781411934A6E",
                    "Serie": "BQ",
                    "Folio": "2205",
                    "Currency": "USD",
                    "ExchangeRate": "19.2107",
                    "PaymentMethod": "PUE",
                    "PartialityNumber": "1",
                    "PreviousBalanceAmount": "1160.00",
                    "AmountPaid": "580.00",
                    "ImpSaldoInsoluto": "580.00"
                }]
            }]
        }
    }

    cfdi_object_complemento_terceros={
        "Receiver": {
            "Name": "Jose de Jesus Romero Alvarado",
            "CfdiUse": "G03",
            "Rfc": "ROAJ850914837"
        },
        "CfdiType": "I",
        "NameId": "01",
        "ExpeditionPlace": "45037",
        "PaymentForm": "01",
        "PaymentMethod": "PUE",
        "Decimals": "2",
        "Currency": "MXN",
        "Date": "2019-06-19T12:45:29",
        "Items": [{
            "Quantity": "1",
            "ProductCode": "10121806",
            "UnitCode": "58",
            "Unit": " kilogramo neto",
            "Description": "consumo",
            "IdentificationNumber": "-",
            "UnitPrice": "1000",
            "Subtotal": "1000.00",
            "Taxes": [{
                "Name": "IVA",
                "Rate": "0.16",
                "Total": "160",
                "Base": "1000",
                "IsRetention": "false",
                "IsFederalTax": "true"
            }],
            "Total": "1160.00",
            "Complement": {
                "ThirdPartyAccount": {
                    "Rfc": "ESO1202108R2",
                    "Name": "Expresion en Software",
                    "Taxes": [{
                        "Name": "IVA",
                        "Rate": "0.16",
                        "Amount": "1000"
                    }]
                }
            }
        }]
    }

    cfdi_object_multi_complemento_pago = {
        "Issuer": {
            "FiscalRegime": "601",
            "Rfc": "AAA010101AAA",
            "Name": "EXPRESION EN SOFTWARE"
        },
        "Receiver": {
            "Name": "SERVICIOS ADMINISTRATIVOS AXKAN DEL BAJIO S.C",
            "CfdiUse": "P01",
            "Rfc": "SAA1609301X7"
        },
        "CfdiType": "P",
        "NameId": "1",
        "Folio": "93",
        "ExpeditionPlace": "76140",
        "Complemento": {
            "Payments": [{
                "Date": "2018-10-04",
                "PaymentForm": "03",
                "Amount": "11142.21",
                "RelatedDocuments": [{
                    "Uuid": "C94C8AF3-C774-4D4C-802E-781411934A6E",
                    "Serie": "BQ",
                    "Folio": "2205",
                    "Currency": "USD",
                    "ExchangeRate": "19.2107",
                    "PaymentMethod": "PUE",
                    "PartialityNumber": "1",
                    "PreviousBalanceAmount": "1160.00",
                    "AmountPaid": "580.00",
                    "ImpSaldoInsoluto": "580.00"
                }]
            }]
        }
    }

    cfdi_object_multi_complemento_donativos= {
        "CfdiType": "I",
        "Currency": "MXN",
        "Date": "2019-06-19T13:45:00",
        "ExpeditionPlace": "51873",
        "NameId": "9",
        "Folio": "94",
        "PaymentForm": "12",
        "PaymentMethod": "PUE",
        "Serie": "Nueva",
        "Complemento": {
            "Donation": {
                "AuthorizationDate": "30/01/2019",
                "AuthorizationNumber": "B400-05-08-2014-005",
                "Legend": "El comprobante es un donativo"
            }
        },
        "Items": [{
            "Description": "Cobija de lana y algodon",
            "IdProduct": "LNzPKg5ydGCdkPAr8W1v7Q2",
            "ProductCode": "20102000",
            "IdentificationNumber": "FP114",
            "Quantity": "3",
            "Subtotal": "3000",
            "Total": "3000",
            "Unit": "NO APLICA",
            "UnitCode": "EA",
            "UnitPrice": "1000"
        }],
        "Issuer": {
            "FiscalRegime": "601",
            "Rfc": "AAA010101AAA",
            "Name": "EXPRESION EN SOFTWARE"
        },
        "Receiver": {
            "CfdiUse": "D04",
            "Name": "Abarrotes del centro",
            "Rfc": "XAXX010101000"
        }
    }

    cfdi_object_multi_complemento_terceros = {
        "Issuer": {
            "FiscalRegime": "601",
            "Rfc": "AAA010101AAA",
            "Name": "EXPRESION EN SOFTWARE"
        },
        "Receiver": {
            "Name": "Jose de Jesus Romero Alvarado",
            "CfdiUse": "G03",
            "Rfc": "ROAJ850914837"
        },
        "CfdiType": "I",
        "NameId": "01",
        "ExpeditionPlace": "45037",
        "PaymentForm": "01",
        "PaymentMethod": "PUE",
        "Folio": "95",
        "Currency": "MXN",
        "Date": "2019-06-19T12:45:29",
        "Items": [{
            "Quantity": "1",
            "ProductCode": "10121806",
            "UnitCode": "58",
            "Unit": " kilogramo neto",
            "Description": "consumo",
            "IdentificationNumber": "-",
            "UnitPrice": "1000",
            "Subtotal": "1000.00",
            "Taxes": [{
                "Name": "IVA",
                "Rate": "0.16",
                "Total": "160",
                "Base": "1000",
                "IsRetention": "false",
                "IsFederalTax": "true"
            }],
            "Total": "1160.00",
            "Complement": {
                "ThirdPartyAccount": {
                    "Rfc": "ESO1202108R2",
                    "Name": "Expresion en Software",
                    "Taxes": [{
                        "Name": "IVA",
                        "Rate": "0.16",
                        "Amount": "1000"
                    }]
                }
            }
        }]
    }


from . import BaseEndpointTestCase


class ProductEndpointTestCase(BaseEndpointTestCase):

    def test_product_create(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        product = self.client.Product.create(self.product_object.copy())
        assert product.Name == 'Sitio Web CMS'
        assert product.IdentificationNumber == 'WEB003'

    def test_product_get(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        product = self.client.Product.all()
        assert product



import base64

from . import BaseEndpointTestCase


class CfdiEndpointTestCase(BaseEndpointTestCase):

    def test_cfdi_get(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        html_file = self.client.Cfdi.get_by_file('html', 'Issued', '7eo51BvzV-E16gBx3nnxfQ2')
        self.client.api_lite = False
        self.client.sandbox = False
        html_name = '{}.html'.format('original')
        with open(html_name, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))

    def test_cfdi_create(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.api_lite = True
        tmp = self.client.Cfdi.create(self.cfdi_object.copy())
        assert tmp

    def test_cfdi_list(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        tmp = self.client.Cfdi.list('issued','Expresion en Software','all')
        assert tmp

    def test_cfdi_email(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        tmp = self.client.Cfdi.send_by_email('issued','GgQKVvV84IlgmFCMqJVraQ2','mail@mail.com')
        assert tmp

    def test_cfdi_saveAsPdf(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = True
        self.client.api_lite = False
        file = self.client.Cfdi.saveAsPdf('7eo51BvzV-E16gBx3nnxfQ2','nombre.pdf')
        assert file

    def test_cfdi_saveAsHtml(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = True
        self.client.api_lite = False
        file = self.client.Cfdi.saveAsHtml('7eo51BvzV-E16gBx3nnxfQ2','nombre.html') #OwMgofF7ZDEM60gerUXudw2
        assert file

    def test_cfdi_complemento(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = True
        self.client.api_lite = False
        tmp = self.client.Cfdi.create(self.cfdi_object_complemento_pago.copy())
        assert tmp

    def test_cfdi_complemento_cuentas_terceros(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = True
        self.client.api_lite = False
        tmp = self.client.Cfdi.create(self.cfdi_object_complemento_terceros.copy())
        assert tmp


from . import BaseEndpointTestCase


class CatalogEndpointTestCase(BaseEndpointTestCase):
    def test_prod_srv_get(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        prod_or_srv = self.client.ProductsServicesCatalog.query({'keyword': 'Caballos'})
        assert prod_or_srv



from . import BaseEndpointTestCase


class BranchOfficeEndpointTestCase(BaseEndpointTestCase):
    def test_branch_create(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        branch = self.client.BranchOffice.create(self.branch_office_object.copy())
        assert branch.Name == 'Corp Inc'

    def test_branch_get(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        branch = self.client.BranchOffice.all()
        assert branch



#!/usr/bin/python
# coding: utf-8
# (c) 2017 Raul Granados <@pollitux>

import base64
from requests import request


try:
    import json
except ImportError:
    import simplejson as json

__version__ = '3.0.5'
__author__ = 'Raul Granados'

api_lite = False
sandbox = False
url_base = ''

_credentials = ('', '')


class FacturamaError(Exception):
    def __init__(self, error_json):
        super(FacturamaError, self).__init__(error_json)
        self.error_json = error_json


class MalformedRequestError(FacturamaError):
    pass


class AuthenticationError(FacturamaError):
    pass


class ProcessingError(FacturamaError):
    pass


class ResourceNotFoundError(FacturamaError):
    pass


class ParameterValidationError(FacturamaError):
    pass


class ApiError(FacturamaError):
    pass


class Facturama:
    """
    Build request facturama API
    """

    _headers = None

    @classmethod
    def aut_api(cls):
        _username, _password = _credentials
        if not _username or not _password:
            raise FacturamaError('Username or password are not set')
        cls._headers = {
            'Authorization': 'Basic %s' % (base64.b64encode(
                ('{}:{}'.format(_username, _password)).encode('utf-8'))).decode('ascii'),
            'content-type': 'application/json'
        }

    @classmethod
    def build_http_request(cls, method, path, payload=None, params=None, version=0):
        """

        :param method: get, post, patch, put
        :param path: resource in the Facturama API
        :param payload: request body
        :param params: query params by url
        :param version: cfdi version 0 api, 1 api and cfdi 3.3, 2 api-lite, 3 api-lite and cfdi 3.3
        :return:
        """
        # urls base of facturama api

        """
        http://api.facturama.mx/2/ - opción 1 api and cfdi 3.3
        http://api.facturama.mx/3/ - opción 5 api and cfdi 4.0
        http://api.facturama.mx/api-lite/2/ - opción 3 api-lite and cfdi 2
        """

        if url_base:
            host = url_base
        else:
            host = 'https://apisandbox.facturama.mx' if sandbox else 'https://api.facturama.mx'

        uris = [
            '{}/api/'.format(host),
            '{}/api/2/'.format(host),
            '{}/api-lite/'.format(host),
            '{}/api-lite/2/'.format(host),
            '{}/retenciones/'.format(host),
            '{}/api/3/'.format(host),
            '{}/api-lite/3/'.format(host),
            '{}/2/retenciones/'.format(host),
        ]
        api_base = uris[version]
        cls.aut_api()
        method = str(method).lower()
        body = request(
            method, '{}{}'.format(api_base, path), data=json.dumps(payload), params=params, headers=cls._headers
        )

        if body.status_code == 200 or body.status_code == 201 or body.status_code == 204:
            response_body = {'status': True}
            try:
                response_body = body.json()
            except Exception:
                pass
            return response_body

        if body.status_code == 400:
            raise MalformedRequestError(body.json())
        elif body.status_code == 401:
            raise AuthenticationError(body.json())
        elif body.status_code == 402:
            raise ProcessingError(body.json())
        elif body.status_code == 404:
            raise ResourceNotFoundError(body.json())
        elif body.status_code == 422:
            raise ParameterValidationError(body.json())
        elif body.status_code == 500:
            raise ApiError(body.json())
        else:
            raise FacturamaError(body.json())

    @classmethod
    def to_object(cls, response):
        for key, value in response.items():
            setattr(cls, key, value)
        return cls

    @classmethod
    def create(cls, data):
        """

        :param data: dict with data for create object
        :return: object with data from response
        """
        return cls.build_http_request('post', cls.__name__, data)

    @classmethod
    def create3(cls, data):
        """

        :param data: dict with data for create object
        :return: object with data from response
        """
        return cls.build_http_request('post', cls.__name__, data)

    @classmethod
    def retrieve(cls, oid, params=None):
        """

        :params oid: id of object retrieve
        :return: object with data from response
        """
        params = {'type':'issued'}
        return cls.build_http_request('get', '{}/{}'.format(cls.__name__, oid), None , params=params)

    @classmethod
    def all(cls, params=None):
        """
        :type params: extra params for build request
        :return: list of objects from response facturama api
        """
        return cls.build_http_request('get', cls.__name__, params=params)

    @classmethod
    def query(cls, params=None):
        """
        :type params: extra params for build request
        :return: list of objects from response facturama api
        """
        return cls.build_http_request('get', cls.__name__, params=params)

    @classmethod
    def update(cls, data, oid):
        """
        :param oid: id object
        :type data: data
        :return: object with data from response
        """
        return cls.build_http_request('put', '{}/{}'.format(cls.__name__, oid), data)

    @classmethod
    def delete(cls, oid):
        """
        :param oid: id object
        :return: None
        """
        return cls.build_http_request('delete', '{}/{}'.format(cls.__name__, oid))


class Client(Facturama):
    """
    Opr with Clients of Facturama API
    """

    @classmethod
    def list(cls, start, length, search):
        """
        :param start: initial search index 
        :param lenght: Size of records displayed (1-100)
        :param search: keyword ()
        """
        v = 0
        return cls.build_http_request(
            'get', '{}?start={}&length={}&search={}'.format('Clients' , start, length, search), version=v
        )


class Product(Facturama):
    """
    Opr with Products of Facturama API
    """
    @classmethod
    def list(cls, start, length, search):
        """
        :param start: initial search index 
        :param lenght: Size of records displayed (1-100)
        :param search: keyword ()
        """
        v = 0
        return cls.build_http_request(
            'get', '{}?start={}&length={}&search={}'.format('Products' , start, length, search), version=v
        )


class BranchOffice(Facturama):
    """
    Opr with Branch Offices of Facturama API
    """

class Customers(Facturama):

    @classmethod
    def validate(cls, params=None):
        """
        Return: object with data.
        """
        v = 0
        return cls.build_http_request('post', '{}/{}'.format(cls.__name__,'validate'), params, version=v)
        

class Cfdi(Facturama):
    """
    Opr with Cfdi of Facturama API
    """
    #CFDI 3.3 URI v=1
    @classmethod
    def create(cls, data, v=1):
        """

        :param v: cfdi version 0 api, 1 api and cfdi 3.3, 2 api-lite, 3 api-lite and cfdi 3.3
        :param data: dict with data for create object
        :return: object with data from response
        """

        return cls.build_http_request('post', 'cfdis' , data, version=v)

    # CFDI 4.0 URI v=5
    @classmethod
    def create3(cls, data, v=5):
        """

        :param v: cfdi version 0 api, 1 api and cfdi 3.3, 2 api-lite, 3 api-lite and cfdi 3.3
        :param data: dict with data for create object
        :return: object with data from response
        """

        return cls.build_http_request('post', 'cfdis' , data, version=v)

    @classmethod
    def get_by_file(cls, f, t, oid):
        """
        :return: get cfdi file by format and type
        """
        return cls.build_http_request('get', '{}/{}/{}/{}'.format(cls.__name__, f, t, oid))

    @classmethod
    def saveAsPdf(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        issued = 'issuedLite' if api_lite else 'issued'
        html_file = cls.get_by_file('pdf', issued, oid)
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def saveAsHtml(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        issued = 'issuedLite' if api_lite else 'issued'
        html_file = cls.get_by_file('html', issued, oid)
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def saveAsXML(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        issued = 'issuedLite' if api_lite else 'issued'
        xml_file = cls.get_by_file('xml', issued, oid)

        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(xml_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def send_by_email(cls, t, oid, email):
        """
        :return: send Cfdi by email
        """
        return cls.build_http_request('post', '{}?cfdiType={}&cfdiId={}&email={}'.format(cls.__name__, t, oid, email))

    @classmethod
    def delete(cls, oid, _type, _motive, _uuidReplacement=None):
        """
        :param oid: id object
        :return: None
        """
        params = {'type':_type, 'motive':_motive, 'uuidReplacement':_uuidReplacement }
        v = 2 if api_lite else 0
        return cls.build_http_request('delete', '{}/{}'.format(cls.__name__ if not api_lite else 'cfdis', oid),params=params, version=v)

    @classmethod
    def list(cls, tipo, keyword, status):
        """
        :param oid: id object
        :return: None
        """
        v = 0
        return cls.build_http_request(
            'get', '{}?type={}&keyword={}&status={}'.format(cls.__name__ , tipo, keyword, status), version=v
        )

    @classmethod
    def listByRfc(cls, tipo, status, rfc):
        """
        :return: None
        """
        v = 0
        return cls.build_http_request(
            'get', '{}?type={}&keyword={}&status={}'.format(cls.__name__ , tipo, status, rfc), version=v
        )

    @classmethod
    def listAll(cls, tipo='issued', folioStart=-1, folioEnd=-1, dateStart='', dateEnd='', rfc='', status='all', orderNumber='', page=0):
        """
        :return: None
        """
        v = 0
        return cls.build_http_request(
            'get', '{}?type={}&folioStart={}&folioEnd={}&dateStart={}&dateEnd={}&rfc={}&status={}&orderNumber={}&page={}'.format(cls.__name__ , tipo, folioStart, folioEnd,rfc,dateStart,dateEnd,status,orderNumber,page), version=v
        )
    
    @classmethod
    def listById(cls, oid, tipe):
        """
        :return: None
        """
        v = 0
        return cls.build_http_request(
            'get', '{}/{}?type={}'.format(cls.__name__ , oid, tipe), version=v
        )
    

class csds(Facturama):
    """
    Opr with csds of Facturama API
    """

    @classmethod
    def get_by_rfc(cls, rfc, v=0):
        """
        get csds by rfc
        :return: object with data from response
        """
        return cls.build_http_request('get', '{}/{}'.format(cls.__name__, rfc), version=v)

    @classmethod
    def create(cls, data):
        raise NotImplemented('Method not implemented')

    @classmethod
    def upload(cls, rfc, path_key, path_cer, password, encode=False, v=0):
        """

        :param encode:
        :param rfc:
        :param path_key:
        :param path_cer:
        :param password:
        :param v:
        :return: object with data from response
        """
        file_key, file_cer = path_key, path_cer
        if not encode:
            with open(path_key, 'rb') as f:
                file_key = base64.b64encode(f.read()).decode('utf-8')

            with open(path_cer, 'rb') as f:
                file_cer = base64.b64encode(f.read()).decode('utf-8')

        data = {
            'Rfc': str(rfc).upper(), 'Certificate': file_cer, 'PrivateKey': file_key, 'PrivateKeyPassword': password
        }
        return cls.build_http_request('post', cls.__name__, data, version=v)


class Catalogs(Facturama):
    catalog = None
    prefix = 'Catalogs'

    @classmethod
    def query(cls, params=None):
        """
        :type params: extra params for build request
        :return: list of objects from response facturama api
        """
        return cls.build_http_request('get', '{}/{}'.format(cls.prefix, cls.catalog), params=params)


class OriginSourcesCatalog(Catalogs):
    """
    Opr with originsources catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'originsources'

class DeductionsCatalog(Catalogs):
    """
    Opr with deductions catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'deductions'

class Incapacities(Catalogs):
    """
    Opr with incapacities catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'incapacities'

class ExtraHours(Catalogs):
    """
    Opr with extrahours catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'extrahours'
class ProductsServicesCatalog(Catalogs):
    """
    Opr with Product or Services catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'ProductsOrServices'
class ContractTypes(Catalogs):
    """
    Opr with ContractTypes catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'ContractTypes'

class Banks(Catalogs):
    """
    Opr with banks catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'banks'
class Perceptions(Catalogs):
    """
    Opr with perceptions catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'perceptions'
class Deductions(Catalogs):
    """
    Opr with deductions catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'deductions'
class OtherPayments(Catalogs):
    """
    Opr with otherpayments catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'otherpayments'
class TypesOfJourney(Catalogs):
    """
    Opr with typesofjourney catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'typesofjourney'
class PositionRisks(Catalogs):
    """
    Opr with positionrisks catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'positionrisks'
class PaymentFrequencies(Catalogs):
    """
    Opr with paymentfrequencies catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'paymentfrequencies'

class RegimenTypes(Catalogs):
    """
    Opr with regimentypes catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'regimentypes'
class PostalCodesCatalog(Catalogs):
    """
    Opr with PostalCodes catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'PostalCodes'

class UnitsCatalog(Catalogs):
    """
    Opr with Units catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'Units'

class CurrenciesCatalog(Catalogs):
    """
    Opr with Currencies catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'Currencies'


class CountriesCatalog(Catalogs):
    """
    Opr with Currencies catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'Countries'


class PaymentFormsCatalog(Catalogs):
    """
    Opr with PaymentForms catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'PaymentForms'


class PaymentMethodsCatalog(Catalogs):
    """
    Opr with PaymentMethods catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'PaymentMethods'


class FederalTaxesCatalog(Catalogs):
    """
    Opr with FederalTaxes catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'FederalTaxes'


class FiscalRegimensCatalog(Catalogs):
    """
    Opr with FiscalRegimens catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'FiscalRegimens'


class CfdiTypesCatalog(Catalogs):
    """
    Opr with CfdiTypes catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'CfdiTypes'


class RelationTypesCatalog(Catalogs):
    """
    Opr with RelationTypes catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'RelationTypes'


class CfdiUsesCatalog(Catalogs):
    """
    Opr with CfdiUses catalog of Facturama API
    """
    prefix = 'catalogs'
    catalog = 'CfdiUses'

class CfdiMultiEmisor(Facturama):
    """
    Opr with Cfdi of Facturama API
    """

    @classmethod
    def create(cls, data, v=3):
        """

        :param v: cfdi version 0 api, 1 api and cfdi 3.3, 2 api-lite, 3 api-lite and cfdi 3.3
        :param data: dict with data for create object
        :return: object with data from response
        """
        return cls.build_http_request('post', cls.__name__ if not api_lite else 'cfdis', data, version=v)

    #CFDI 4.0 Multiemisor
    @classmethod
    def create3(cls, data, v=6):
        """

        :param v: 6 for /api-lite/3/
        :param data: dict with data for create object
        :return: object with data from response
        """
        return cls.build_http_request('post', cls.__name__ if not api_lite else 'cfdis', data, version=v)


    @classmethod
    def retrieve(cls, oid, params=None):
        """

        :params oid: id of object
        :return: object with data from response
        """
        return cls.build_http_request('get', '{}/{}'.format('cfdis', oid), params=params, version=2)
        #return cls.build_http_request('get', '{}/{}'.format('cfdis', oid), version=3)

    @classmethod
    def get_by_file(cls, f, t, oid):
        """
        :return: get cfdi file by format and type
        """
        return cls.build_http_request('get', '{}/{}/{}/{}'.format('Cfdi', f, t, oid))

    @classmethod
    def saveAsPdf(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        html_file = cls.get_by_file('pdf', 'IssuedLite',oid)
        cls.api_lite = True
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def saveAsHtml(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        html_file = cls.get_by_file('html', 'IssuedLite', oid)
        cls.api_lite = True
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def saveAsXML(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        xml_file = cls.get_by_file('xml', 'IssuedLite', oid)
        cls.api_lite = True
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(xml_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def delete(cls, oid, _motive, _uuidReplacement=None):
        """
        :param oid: id object
        :return: None
        """
        params = {'motive':_motive, 'uuidReplacement':_uuidReplacement }
        return cls.build_http_request('delete', '{}/{}'.format('cfdis', oid),params=params, version=2)

    @classmethod
    def list(cls, filters):
        """
        :param filters: dict filters
        :return: None
        """
        return cls.build_http_request('get','cfdis', params=filters, version=2)


    @classmethod
    def detail(cls, oid):
        """
        :param oid: id object
        :return: None
        """
        return cls.build_http_request('get', '{}/{}'.format('cfdis', oid), version=2)


class csdsMultiEmisor(Facturama):
    """
    Opr with csds of Facturama API
    """

    @classmethod
    def get_by_rfc(cls, rfc):
        """
        get csds by rfc
        :return: object with data from response
        """
        return cls.build_http_request('get', '{}/{}'.format('csds', rfc), version=2)

    @classmethod
    def create(cls, data):
        raise NotImplemented('Method not implemented')

    @classmethod
    def upload(cls, rfc, path_key, path_cer, password, encode=False):
        """

        :param encode:
        :param rfc:
        :param path_key:
        :param path_cer:
        :param password:
        :param v:
        :return: object with data from response
        """
        file_key, file_cer = path_key, path_cer
        if not encode:
            with open(path_key, 'rb') as f:
                file_key = base64.b64encode(f.read()).decode('utf-8')

            with open(path_cer, 'rb') as f:
                file_cer = base64.b64encode(f.read()).decode('utf-8')

        data = {
            'Rfc': str(rfc).upper(), 'Certificate': file_cer, 'PrivateKey': file_key, 'PrivateKeyPassword': password
        }
        return cls.build_http_request('post', 'csds', data, version=2)

    @classmethod
    def update(cls, rfc, path_key, path_cer, password, encode=False):
        """

        :param encode:
        :param rfc:
        :param path_key:
        :param path_cer:
        :param password:
        :param v:
        :return: object with data from response
        """
        file_key, file_cer = path_key, path_cer
        if not encode:
            with open(path_key, 'rb') as f:
                file_key = base64.b64encode(f.read()).decode('utf-8')

            with open(path_cer, 'rb') as f:
                file_cer = base64.b64encode(f.read()).decode('utf-8')

        data = {
            'Rfc': str(rfc).upper(), 'Certificate': file_cer, 'PrivateKey': file_key, 'PrivateKeyPassword': password
        }
        return cls.build_http_request('put', '{}/{}'.format('csds', rfc), data, version=2)


    @classmethod
    def delete(cls, rfc):
        """
        get csds by rfc
        :return: object with data from response
        """
        return cls.build_http_request('delete', '{}/{}'.format('csds', rfc), version=2)

    @classmethod
    def get(cls):
        """
        get csds by rfc
        :return: object with data from response
        """
        return cls.build_http_request('get', '{}'.format('csds'), version=2)


class Retentions(Facturama):
    """
    Opr with Cfdi of Facturama API
    """

    @classmethod
    def create(cls, data):
        """
        :param data: dict with data for create object
        :return: object with data from response
        """
        return cls.build_http_request('post', '', data, version=4)

    @classmethod
    def retrieve(cls, oid, params=None):
        """
        :params oid: id of object
        :return: object with data from response
        """
        return cls.build_http_request('get', oid, params=params, version=4)

    @classmethod
    def get_by_file(cls, format, oid):
        """
        :return: get cfdi file by format and type
        """
        return cls.build_http_request('get', '{}/{}'.format(oid, format), params=None, version=4)

    @classmethod
    def saveAsPdf(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        html_file = cls.get_by_file('pdf', oid)
        cls.api_lite = True
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def saveAsHtml(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        html_file = cls.get_by_file('html', oid)
        cls.api_lite = True
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def saveAsXML(cls, oid, fileName):
        """
        :return: get cfdi file by format and type
        """
        xml_file = cls.get_by_file('xml', oid)
        cls.api_lite = True
        with open(fileName, 'wb') as f:
            f.write(base64.urlsafe_b64decode(xml_file['Content'].encode('utf-8')))
        return f

    @classmethod
    def delete(cls, oid):
        """
        :param oid: id object
        :return: None
        """
        return cls.build_http_request(
            'delete', oid, version=4)

    @classmethod
    def list(cls, filters = None):
        """
        :param filters: dict filters
        :return: None
        """
        return cls.build_http_request('get','', params=filters, version=4)

    @classmethod
    def sendByMail(cls, oid, email):
        """
        :param filters: dict filters
        :return: None
        """
        return cls.build_http_request('post','envia?id={}&email={}'.format(oid, email), None, version=4)



import base64

from . import BaseEndpointTestCase


class CfdiMultiEndpointTestCase(BaseEndpointTestCase):

    def test_cfdi_get(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        html_file = self.client.CfdiMultiEmisor.get_by_file('html', 'IssuedLite', 'o9Vy0QfumyYEcOuu3S-7Cw2')
        self.client.api_lite = True
        self.client.sandbox = False
        html_name = '{}.html'.format('original')
        with open(html_name, 'wb') as f:
            f.write(base64.urlsafe_b64decode(html_file['Content'].encode('utf-8')))

    def test_cfdi_create(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.api_lite = True
        self.client.sandbox = False
        tmp = self.client.CfdiMultiEmisor.create(self.cfdi_object.copy())
        assert tmp

    def test_cfdi_list(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = False
        filter = dict(rfc='XAXX010101000',
                      folioStart = 100,
                      folioEnd = 200
                )
        tmp = self.client.CfdiMultiEmisor.list(filter)
        assert tmp

    def test_cfdi_saveAsPdf(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = False
        file = self.client.CfdiMultiEmisor.saveAsPdf('o9Vy0QfumyYEcOuu3S-7Cw2','nombre.pdf')
        assert file

    def test_cfdi_saveAsHtml(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = False
        file = self.client.CfdiMultiEmisor.saveAsHtml('o9Vy0QfumyYEcOuu3S-7Cw2','nombre.html')
        assert file

    def test_cfdi_detail(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = False
        detailInfo = self.client.CfdiMultiEmisor.detail('o9Vy0QfumyYEcOuu3S-7Cw2')
        assert detailInfo

    def test_cfdi_complemento(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.api_lite = True
        self.client.sandbox = True
        tmp = self.client.CfdiMultiEmisor.create(self.cfdi_object_multi_complemento_pago.copy())
        assert tmp

    def test_cfdi_complemento_donativos(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.api_lite = True
        self.client.sandbox = True
        tmp = self.client.CfdiMultiEmisor.create(self.cfdi_object_multi_complemento_donativos.copy())
        assert tmp

    def test_cfdi_complemento_cuenta_terceros(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.api_lite = True
        self.client.sandbox = True
        tmp = self.client.CfdiMultiEmisor.create(self.cfdi_object_multi_complemento_terceros.copy())
        assert tmp



from . import BaseEndpointTestCase


class CSDSMultiEndpointTestCase(BaseEndpointTestCase):
    def test_csds(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = True
        csd = self.client.csdsMultiEmisor.get_by_rfc('UN-RFC')
        assert csd.status

    def getCurrentCsds(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.sandbox = True
        currentCsds = self.client.csdsMultiEmisor.get()
        assert currentCsds

    def test_csds_full(self){
        self.client._credentials = ('pruebas', 'pruebas2011')

        self.client.api_lite = True
        self.client.sandbox = True    

        # carga  un nuevo certificado para el RFC
        self.client.csdsMultiEmisor.upload('UN-RFC', 'key.key', 'cert.cer', '12345678a')

        #Edita el certificado para el RFC
        self.client.csdsMultiEmisor.update('UN-RFC', 'key.key', 'cert.cer', '12345678a')

        #Obtiene el certificado asociado al RFC
        csd = self.client.csdsMultiEmisor.get_by_rfc('UN-RFC')    
        print csd.Rfc    

        # Elimina el certificado del RFC
        self.client.csdsMultiEmisor.delete('UN-RFC')
    }


from . import BaseEndpointTestCase


class CustomerEndpointTestCase(BaseEndpointTestCase):
    def test_customer_create(self):
        self.client._credentials = ('pruebas', 'pruebas2011')

        customer = self.client.Client.create(self.customer_object.copy())
        assert customer.Id

    def test_customer_get(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        customer = self.client.Client.retrieve('98DY-y6qSikkykW2nhp9kw2')
        assert customer.Id

    def test_customer_get_all(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        customer = self.client.Client.all()
        assert customer



#!/usr/bin/python
# coding: utf-8
# (c) 2017 Raul Granados <@pollitux>

from setuptools import setup, find_packages

version = '2.0.5'
author = 'Tingsystems'

setup(
    name='facturama',
    version=version,
    author=author,
    author_email='soporte@tingsystems.com',
    url='https://github.com/tingsystems/facturama',
    description='Easy Facturama python wrapper',
    long_description=open('./README.txt', 'r').read(),
    download_url='https://github.com/tingsystems/facturama/master',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'License :: OSI Approved :: MIT License',
    ],
    packages=find_packages(),
    install_requires=[
        'requests',
        'simplejson',
        'nose'
    ],
    license='MIT License',
    keywords='facturama wrapper',
    include_package_data=True,
    zip_safe=True,
)



from . import BaseEndpointTestCase


class CSDSEndpointTestCase(BaseEndpointTestCase):
    def test_csds(self):
        self.client._credentials = ('pruebas', 'pruebas2011')
        self.client.api_lite = True
        self.client.sandbox = True
        self.client.csds.upload('rfc', 'csds.key', 'csds.cer', 'pass', v=2)
        csd = self.client.csds.get_by_rfc('rfc', v=2)
        assert csd.status
